.embed {
    border-radius: 5px;
    padding: 10px;
    background-color: rgba(0.0, 0.0, 0.0, 0.1);
}

.embed-footer {
    margin-top: 5px;
    font-size: 11px;
}

.embed-author {
    margin-bottom: 10px;
    font-size: 12px;
}

.message-attachment-box {
    border: 1px solid #aaaaaa;
    padding: 2px 5px 2px 5px;
}

.message-attachment-box label {
    margin: 5px;
}

.status-indicator.dnd {
    color: #982929;
}

.status-indicator.online {
    color: #43B581;
}

.status-indicator.offline {
    color: #808080;
}

.status-indicator.idle {
    color: #FAA61A;
}

.message-container {
    margin-bottom: 8px;
}

.message-input textview, .message-input textview text {
    background-color: inherit;
}

.message-text, .message-text text {
    background: inherit;
}

.message-input textview {
    padding: 10px 5px;
}

.message-reply {
    border-left: 2px solid gray;
    padding-left: 10px;
    padding-top: 6px;
    padding-bottom: 6px;
    opacity: 0.8;
}

.profile-main-container {
    padding: 20px;
}

.profile-username {
    margin-left: 10px;
    font-size: 20px;
}

.profile-username-nondisplay {
    margin-left: 10px;
}

.profile-switcher {
    padding-top: 5px;
}

.profile-stack {
    padding-top: 5px;
}

.profile-notes-label {
    padding-top: 5px;
    padding-bottom: 5px;
}

.profile-badges {
    padding-left: 5px;
}

.profile-badge {
    margin-right: 5px;
}

.profile-connections {
    margin-top: 10px;
}

.profile-connection {
    padding: 5px;
    border-radius: 10px;
    border: 1px solid @theme_fg_color;
}

.profile-connection-image {
    padding-right: 5px;
}

.reaction-box {
    padding: 2px 5px 2px 5px;
    border-radius: 5px;
    border: 1px solid @theme_fg_color;
}

.reaction-box.reacted {
    border: 1px solid #5865f2;
    background-color: alpha(@theme_selected_bg_color, 0.5);
}

.set-status-dialog .dialog-vbox {
    padding: 5px;
}

.set-status-dialog .dialog-action-area {
    margin: 10px 5px 5px 5px;
}

.voice-settings-window > box {
    padding: 5px;
}

.voice-settings-window scale {
    margin-right: 8px;
}

.message-input scrollbar.vertical slider {
    min-height: 0px;
}

.message-text.pending {
    color: alpha(currentColor, 0.5);
}

.message-text.failed {
    color: red;
}

.guild-list-scroll > scrollbar {
    border: none;
}

.guild-list-scroll > scrollbar slider {
    border: none;
    margin: 0px;
    min-width: 0px;
    min-height: 0px;
}

.classic-mention-overlay:selected {
    color: @theme_selected_color;
    background-color: @theme_selected_bg_color;
}

.channel-list .view:selected {
    background-color: @theme_selected_bg_color;
}

.classic-guild-list > row {
    padding-left: 0px;
    box-shadow: none;
    border: none;
    outline: none;
}

.classic-guild-list > row:hover {
    background: none;
}

.classic-guild-list-guild.has-unread {
    background: radial-gradient(7px circle at left, @theme_selected_bg_color 50%, transparent 20%);
}

.classic-guild-list-folder.has-unread stack {
    background: radial-gradient(7px circle at left, @theme_selected_bg_color 50%, transparent 20%);
}

.classic-guild-list-guild box, .classic-guild-list-folder stack {
    padding-left: 10px;
}
